@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2005 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2006 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -217,10 +217,10 @@ load_pixbuf (struct sebie_s *sebie)
     g_object_unref(sebie->model.image_pixbuf);
   }
   sebie->model.image_pixbuf = pixbuf;
-  double scale1 = 1024.0 / (double)sebie->model.image_width;
-  double scale2 =  768.0 / (double)sebie->model.image_width;
-  double scale3 = 1024.0 / (double)sebie->model.image_height;
-  double scale4 =  768.0 / (double)sebie->model.image_height;
+  double scale1 = (double)sebie->model.pixbuf_width / (double)sebie->model.image_width;
+  double scale2 = (double)sebie->model.pixbuf_height / (double)sebie->model.image_width;
+  double scale3 = (double)sebie->model.pixbuf_width / (double)sebie->model.image_height;
+  double scale4 = (double)sebie->model.pixbuf_height / (double)sebie->model.image_height;
     
   scale1 = MIN(scale1, scale2);
   scale1 = MIN(scale1, scale3);
@@ -337,6 +337,10 @@ save_sebie_config(struct sebie_s *sebie)
       { "ImageOutputHeight", CONFIG_INTEGER, &sebie->model.selection_fac_height, 768},
       { "ImageGamma", CONFIG_DOUBLE, &sebie->model.image_gamma, 1.0},
       { "ImageGrayscale", CONFIG_INTEGER, &sebie->model.image_grayscale, 0},
+      { "Window1Width", CONFIG_INTEGER, &sebie->model.window1_width, 1187},
+      { "Window1Height", CONFIG_INTEGER, &sebie->model.window1_height, 832},
+      { "PixbufWidth",  CONFIG_INTEGER, &sebie->model.pixbuf_width, 1024},
+      { "PixbufHeight", CONFIG_INTEGER, &sebie->model.pixbuf_height, 768},
       { NULL, CONFIG_END, NULL, 0}
     };
     sebie_write_config(sebie->config_file, config_spec);
@@ -366,6 +370,10 @@ init_sebie_model(struct sebie_s *sebie)
     { "ImageOutputHeight", CONFIG_INTEGER, &sebie->model.selection_fac_height, 768},
     { "ImageGamma", CONFIG_DOUBLE, &sebie->model.image_gamma, 1.0},
     { "ImageGrayscale", CONFIG_INTEGER, &sebie->model.image_grayscale, 0},
+    { "Window1Width", CONFIG_INTEGER, &sebie->model.window1_width, 1187},
+    { "Window1Height", CONFIG_INTEGER, &sebie->model.window1_height, 832},
+    { "PixbufWidth",  CONFIG_INTEGER, &sebie->model.pixbuf_width, 1024},
+    { "PixbufHeight", CONFIG_INTEGER, &sebie->model.pixbuf_height, 768},
     { NULL, CONFIG_END, NULL, 0}
   };
   
@@ -389,7 +397,7 @@ init_sebie_model(struct sebie_s *sebie)
   sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_FAC_H;
   sebie->dirty_tags |= SEBIE_UPDATE_IMAGE_GAMMA;
   
-  sebie->model.statusbar_text = strdup("   SeBIE  (C) 2002-2005 by Peter.Seiderer@ciselant.de");
+  sebie->model.statusbar_text = strdup("   SeBIE  (C) 2002-2006 by Peter.Seiderer@ciselant.de");
   sebie->dirty_tags |= SEBIE_UPDATE_STATUS_BAR;
 }
 
