@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2005 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2006 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -55,7 +55,8 @@ typedef enum sebie_model_tag_e {
   SEBIE_MODEL_OUTPUT_FORMAT          =   4,
   SEBIE_MODEL_UPDATE_SELECTION_FAC   =   8,
   SEBIE_MODEL_UPDATE_GAMMA           =  16,
-  SEBIE_MODEL_UPDATE_GRAYSCALE       =  32
+  SEBIE_MODEL_UPDATE_GRAYSCALE       =  32,
+  SEBIE_MODEL_CHANGE_PIXBUF_SIZE     =  64
 } sebie_model_tag;
 
 typedef enum sebie_mouse_click_e {
@@ -125,8 +126,12 @@ typedef struct sebie_model_s {
   gint image_height;
   /* the scaled one for the preview */
   double scaled_scale;
-  /* here is the original scaled pixbuf sotred */
+  /* here is the original scaled pixbuf stored */
   GdkPixbuf *scaled_pixbuf_orig;
+  gint window1_width;
+  gint window1_height;
+  gint pixbuf_width;
+  gint pixbuf_height;
   /* and here the one with the color corrections applied,
    * which is drawed to the screen */
   GdkPixbuf *scaled_pixbuf;
