@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2005 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2006 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -103,6 +103,52 @@ on_entry_output_format_changed (GtkEditable *editable,
   save_sebie_config(sebie);
 }
 
+
+gint
+window1_delete_event (GtkWidget *widget,
+		      GdkEvent  *event,
+		      gpointer   data)
+{
+    sebie_debug("window1_delete_event\n");
+    return FALSE;
+}
+
+
+void
+window1_destroy (GtkWidget *widget,
+		 gpointer   data)
+{
+    sebie_debug("window1_destroy\n");
+    gtk_main_quit ();
+}
+
+
+void
+drawingarea1_size_allocate (GtkWidget *widget,
+			    GtkAllocation *allocation,
+			    gpointer   user_data)
+{
+    struct sebie_s *sebie = (struct sebie_s *)user_data;
+    gint window1_width;
+    gint window1_height;
+
+    sebie_debug("drawingarea1_size_allocate x = %d y = %d width = %d height = %d\n",
+		allocation->x,
+		allocation->y,
+		allocation->width,
+		allocation->height);
+ 
+    gtk_window_get_size(sebie->view.window1, &window1_width, &window1_height);
+    sebie->model.window1_width = window1_width;
+    sebie->model.window1_height = window1_height;
+    sebie->model.pixbuf_width = allocation->width;
+    sebie->model.pixbuf_height = allocation->height;
+ 
+    sebie->model_tags |= SEBIE_MODEL_CHANGE_PIXBUF_SIZE;
+    save_sebie_config(sebie);
+}
+
+
 void
 on_button_quit_clicked (GtkButton *button,
 			gpointer  user_data)
@@ -312,11 +358,11 @@ on_entry_selection_gamma_changed (GtkEditable *editable,
 }
 
 void
-on_button_grayscale_clicked(GtkButton *button,
+on_button_grayscale_clicked(GtkToggleButton *button,
 			    gpointer  user_data)
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
-  sebie->model.image_grayscale = !sebie->model.image_grayscale;
+  sebie->model.image_grayscale = gtk_toggle_button_get_active (button);
   sebie_debug("set new image_grayscale = %d\n", sebie->model.image_grayscale);
   sebie->model_tags |= SEBIE_MODEL_UPDATE_GRAYSCALE;
   apply_color_corrections(sebie);
