@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2005 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -19,7 +19,9 @@
  *
  */
 #include "sebie_helpers.h"
-
+#include <stdarg.h>
+#include <stdlib.h>
+#include <stdio.h>
 
 void
 sebie_set_string(gchar **old_text, const gchar *new_text)
@@ -29,3 +31,25 @@ sebie_set_string(gchar **old_text, const gchar *new_text)
   }
   *old_text = g_strdup(new_text);
 }
+
+void
+sebie_error(const char *format, ...)
+{  
+  va_list ap;
+  va_start(ap, format);
+  vfprintf(stderr, format, ap);
+  va_end(ap);
+}
+
+void
+sebie_debug(const char *format, ...)
+{
+  char *sebie_debug;
+  
+  if ((sebie_debug = getenv("SEBIE_DEBUG")) != NULL) {
+    va_list ap;
+    va_start(ap, format);
+    vprintf(format, ap);
+    va_end(ap);
+  }
+}
