@@ -39,8 +39,9 @@ init_sebie_view(struct sebie_s *sebie)
  
   sebie->view.window1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gchar * window1_title = "SeBIE " PACKAGE_VERSION ;
+  gtk_widget_set_name (sebie->view.window1, window1_title);
   gtk_window_set_title (GTK_WINDOW (sebie->view.window1), window1_title);
-  
+
   sebie->view.vbox1 = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (sebie->view.vbox1);
   gtk_container_add (GTK_CONTAINER (sebie->view.window1), sebie->view.vbox1);
@@ -187,7 +188,7 @@ init_sebie_view(struct sebie_s *sebie)
   gtk_entry_set_max_length (GTK_ENTRY (sebie->view.entry_selection_gamma), 5);
 
   sebie->view.button_grayscale = gtk_toolbar_append_element (GTK_TOOLBAR (sebie->view.toolbar1),
-							     GTK_TOOLBAR_CHILD_BUTTON,
+							     GTK_TOOLBAR_CHILD_TOGGLEBUTTON,
 							     NULL,
 							     _("Grayscale"),
 							     NULL, NULL,
@@ -253,7 +254,10 @@ init_sebie_view(struct sebie_s *sebie)
   sebie->view.drawingarea1 = gtk_drawing_area_new ();
   gtk_widget_show (sebie->view.drawingarea1);
   gtk_paned_pack2 (GTK_PANED (sebie->view.hpaned1), sebie->view.drawingarea1, TRUE, TRUE);
-  gtk_widget_set_size_request (sebie->view.drawingarea1, 1024, 768);
+
+  gtk_window_set_default_size(sebie->view.window1,
+			      sebie->model.window1_width,
+			      sebie->model.window1_height);
 
   sebie->view.statusbar1 = gtk_statusbar_new ();
   gtk_widget_show (sebie->view.statusbar1);
@@ -274,6 +278,15 @@ init_sebie_view(struct sebie_s *sebie)
   g_signal_connect ((gpointer) sebie->view.entry_output_format, "changed",
                     G_CALLBACK (on_entry_output_format_changed),
                     sebie);
+
+  g_signal_connect (G_OBJECT (sebie->view.window1), "delete-event",
+		    G_CALLBACK (window1_delete_event), NULL);
+  g_signal_connect (G_OBJECT (sebie->view.window1), "destroy",
+		    G_CALLBACK (window1_destroy), NULL);
+
+  g_signal_connect (G_OBJECT (sebie->view.drawingarea1), "size-allocate",
+		    G_CALLBACK (drawingarea1_size_allocate), sebie);
+
   g_signal_connect ((gpointer) sebie->view.button_quit, "clicked",
                     G_CALLBACK (on_button_quit_clicked),
                     sebie);
